@@ -152,26 +152,7 @@ DavUtils::Protocol DavUtils::DavUrl::protocol() const
   return mProtocol;
 }
 
-QLatin1String DavUtils::protocolName( DavUtils::Protocol protocol )
-{
-  QLatin1String protocolName( "" );
-
-  switch( protocol ) {
-    case DavUtils::CalDav:
-      protocolName = QLatin1String( "CalDav" );
-      break;
-    case DavUtils::CardDav:
-      protocolName = QLatin1String( "CardDav" );
-      break;
-    case DavUtils::GroupDav:
-      protocolName = QLatin1String( "GroupDav" );
-      break;
-  }
-
-  return protocolName;
-}
-
-QString DavUtils::translatedProtocolName( DavUtils::Protocol protocol )
+QString DavUtils::protocolName( DavUtils::Protocol protocol )
 {
   QString protocolName;
 
@@ -192,7 +173,7 @@ QString DavUtils::translatedProtocolName( DavUtils::Protocol protocol )
 
 DavUtils::Protocol DavUtils::protocolByName( const QString &name )
 {
-  DavUtils::Protocol protocol;
+  DavUtils::Protocol protocol = DavUtils::CalDav;
 
   if ( name == "CalDav" ) {
     protocol = DavUtils::CalDav;
@@ -200,21 +181,8 @@ DavUtils::Protocol DavUtils::protocolByName( const QString &name )
     protocol = DavUtils::CardDav;
   } else if ( name == "GroupDav" ) {
     protocol = DavUtils::GroupDav;
-  }
-
-  return protocol;
-}
-
-DavUtils::Protocol DavUtils::protocolByTranslatedName( const QString &name )
-{
-  DavUtils::Protocol protocol;
-
-  if ( name == i18n( "CalDav" ) ) {
-    protocol = DavUtils::CalDav;
-  } else if ( name == i18n( "CardDav" ) ) {
-    protocol = DavUtils::CardDav;
-  } else if ( name == i18n( "GroupDav" ) ) {
-    protocol = DavUtils::GroupDav;
+  } else {
+    kError() << "Unexpected protocol name : " << name;
   }
 
   return protocol;
@@ -255,7 +223,7 @@ DavItem DavUtils::createDavItem( const Akonadi::Item &item, const Akonadi::Colle
   } else if ( item.hasPayload<IncidencePtr>() ) {
     const IncidencePtr ptr = item.payload<IncidencePtr>();
 
-    const QString fileName = ptr->uid();
+    const QString fileName = ptr->instanceIdentifier();
     if ( fileName.isEmpty() ) {
       kError() << "Invalid incidence uid";
       return davItem;
