@@ -71,12 +71,12 @@ class Settings : public SettingsBase
      */
     DavUtils::DavUrl configuredDavUrl( DavUtils::Protocol protocol, const QString &searchUrl, const QString &finalUrl = QString() );
 
-	/**
-	 * Creates and return the DavUrl from the configured URL that has a mapping with @p collectionUrl.
-	 * If @p finalUrl is supplied it will be used in the returned object, else @p collectionUrl will
-	 * be used.
-	 * If no configured URL can be found the returned DavUrl will have an empty url().
-	 */
+        /**
+         * Creates and return the DavUrl from the configured URL that has a mapping with @p collectionUrl.
+         * If @p finalUrl is supplied it will be used in the returned object, else @p collectionUrl will
+         * be used.
+         * If no configured URL can be found the returned DavUrl will have an empty url().
+         */
      DavUtils::DavUrl davUrlFromCollectionUrl( const QString &collectionUrl, const QString &finalUrl = QString() );
 
     /**
@@ -117,7 +117,6 @@ class Settings : public SettingsBase
     QString promptForPassword( const QString &user );
 
     void updateToV2();
-    void updateToV3();
 
     WId mWinId;
     QString mResourceIdentifier;
