@@ -42,11 +42,8 @@ ResourceTask::ResourceTask( ActionIfNoSession action, ResourceStateInterface::Pt
 
 ResourceTask::~ResourceTask()
 {
-  if ( m_pool ) {
-    if ( m_sessionRequestId )
-      m_pool->cancelSessionRequest( m_sessionRequestId );
-    if ( m_session )
-      m_pool->releaseSession( m_session );
+  if ( m_pool && m_session ) {
+    m_pool->releaseSession( m_session );
   }
 }
 
@@ -189,6 +186,11 @@ Akonadi::Item ResourceTask::item() const
   return m_resource->item();
 }
 
+Akonadi::Item::List ResourceTask::items() const
+{
+  return m_resource->items();
+}
+
 Akonadi::Collection ResourceTask::parentCollection() const
 {
   return m_resource->parentCollection();
@@ -209,6 +211,16 @@ QSet<QByteArray> ResourceTask::parts() const
   return m_resource->parts();
 }
 
+QSet< QByteArray > ResourceTask::addedFlags() const
+{
+  return m_resource->addedFlags();
+}
+
+QSet< QByteArray > ResourceTask::removedFlags() const
+{
+  return m_resource->removedFlags();
+}
+
 QString ResourceTask::rootRemoteId() const
 {
   return m_resource->rootRemoteId();
@@ -265,6 +277,12 @@ void ResourceTask::changeCommitted( const Akonadi::Item &item )
   deleteLater();
 }
 
+void ResourceTask::changesCommitted(const Akonadi::Item::List& items)
+{
+  m_resource->itemsChangesCommitted( items );
+  deleteLater();
+}
+
 void ResourceTask::collectionsRetrieved( const Akonadi::Collection::List &collections )
 {
   m_resource->collectionsRetrieved( collections );
