@@ -529,12 +529,7 @@ void KABCResource::collectionChanged( const Akonadi::Collection &collection )
   }
 
   if ( collection.parentCollection() == Collection::root() ) {
-    QString newName = collection.name();
-    if ( collection.hasAttribute<EntityDisplayAttribute>() ) {
-      EntityDisplayAttribute *attr = collection.attribute<EntityDisplayAttribute>();
-      if ( !attr->displayName().isEmpty() )
-        newName = attr->displayName();
-    }
+    const QString newName = collection.displayName();
 
     if ( newName != mBaseResource->resourceName() ) {
       mBaseResource->setResourceName( newName );
